==> pygerber-2.0.0rc1.tar.gz: pygerber-2.0.0rc1/src/pygerber/backend/abstract/draw_commands/draw_vector_line.py <==
"""# DrawVectorLine Module.

This module defines the base class for creating vector line components
used in drawing creation. The main class, `DrawVectorLine`, represents
a vector line defined by its start and end positions and width.
"""
from __future__ import annotations

from pygerber.backend.abstract.backend_cls import Backend
from pygerber.backend.abstract.bounding_box import BoundingBox
from pygerber.backend.abstract.draw_commands.draw_command import DrawCommand
from pygerber.backend.abstract.offset import Offset
from pygerber.backend.abstract.vector_2d import Vector2D
from pygerber.gerberx3.state_enums import Polarity


class DrawVectorLine(DrawCommand):
    """Represents a vector line component used in drawing creation.
    This class is defined by its start position, end position, and width.
    """

    start_position: Vector2D
    end_position: Vector2D
    width: Offset

    def __init__(  # noqa: PLR0913
        self,
        backend: Backend,
        polarity: Polarity,
        start_position: Vector2D,
        end_position: Vector2D,
        width: Offset,
    ) -> None:
        """Initialize draw command."""
        super().__init__(backend, polarity)
        self.start_position = start_position
        self.end_position = end_position
        self.width = width

    def get_bounding_box(self) -> BoundingBox:
        """Return bounding box of draw operation."""
        vertex_box = BoundingBox.from_diameter(self.width)
        return (vertex_box + self.start_position) + (vertex_box + self.end_position)

==> pygerber-2.0.1.tar.gz: pygerber-2.0.1/src/pygerber/backend/abstract/draw_commands/draw_vector_line.py <==
"""# DrawVectorLine Module.

This module defines the base class for creating vector line components
used in drawing creation. The main class, `DrawVectorLine`, represents
a vector line defined by its start and end positions and width.
"""
from __future__ import annotations

from pygerber.backend.abstract.backend_cls import Backend
from pygerber.backend.abstract.draw_commands.draw_command import DrawCommand
from pygerber.gerberx3.math.bounding_box import BoundingBox
from pygerber.gerberx3.math.offset import Offset
from pygerber.gerberx3.math.vector_2d import Vector2D
from pygerber.gerberx3.state_enums import Polarity


class DrawVectorLine(DrawCommand):
    """Represents a vector line component used in drawing creation.
    This class is defined by its start position, end position, and width.
    """

    start_position: Vector2D
    end_position: Vector2D
    width: Offset

    def __init__(  # noqa: PLR0913
        self,
        backend: Backend,
        polarity: Polarity,
        start_position: Vector2D,
        end_position: Vector2D,
        width: Offset,
    ) -> None:
        """Initialize draw command."""
        super().__init__(backend, polarity)
        self.start_position = start_position
        self.end_position = end_position
        self.width = width

    def get_bounding_box(self) -> BoundingBox:
        """Return bounding box of draw operation."""
        vertex_box = BoundingBox.from_diameter(self.width)
        return (vertex_box + self.start_position) + (vertex_box + self.end_position)

    def __str__(self) -> str:
        return (
            f"{self.__class__.__qualname__}({self.polarity}) start: "
            "{self.start_position} end: {self.end_position}"
        )
